<?php
$lang['invalidemail'] = 'Vložen&aacute; emailov&aacute; adresa je neplatn&aacute;';
$lang['empty_query'] = 'Pr&aacute;zdn&yacute; dotaz?? %s';
$lang['no_db_driver'] = 'Nenalezeny kompatibiln&iacute; ovladače datab&aacute;ze';
$lang['test_check_output_buffering'] = 'Kontroluje se v&yacute;stupn&iacute; vyrovn&aacute;v&aacute;n&iacute;';
$lang['test_check_output_buffering_failed'] = 'V&yacute;stupn&iacute; vyrovn&aacute;v&aacute;n&iacute; je zak&aacute;z&aacute;no. Pravděpodobně nebudete moci použ&iacute;vat ž&aacute;dnou funkcionalitu, kter&aacute; to vyžaduje';
$lang['phpinfo'] = 'Zobrazit informace o PHP';
$lang['mod_security'] = 'Apache Mod Security';
$lang['test_check_tempnam'] = 'Kontroluje se tempnam funkce';
$lang['test_check_db_drivers'] = 'Ovladače datab&aacute;ze';
$lang['test_check_db_drivers_failed'] = 'Nebyly nalezeny ovladače datab&aacute;ze';
$lang['test_check_register_globals'] = 'Kontroluje se register_globals';
$lang['test_check_register_globals_failed'] = 'V nastaven&iacute; PHP je aktivov&aacute;na volba register_globals. Z bezpečnostn&iacute;ch důvodů pros&iacute;m pož&aacute;dejte o vypnut&iacute; t&eacute;to volby.';
$lang['test_check_disable_functions'] = 'Kontroluj&iacute; se zak&aacute;zan&eacute; funkce v PHP';
$lang['test_check_disable_functions_failed'] = 'Toto je seznam funkc&iacute; zak&aacute;zan&yacute;ch na va&scaron;em serveru.';
$lang['install_admin_db_port'] = 'Port Datab&aacute;ze';
$lang['install_admin_db_port_info'] = 'Pokud si nejse jisti, zanechte toto pr&aacute;zdn&eacute; pro v&yacute;choz&iacute; nastaven&iacute;.';
$lang['install_admin_db_socket'] = 'Socket datab&aacute;ze';
$lang['install_admin_db_socket_info'] = 'NEPODPOROV&Aacute;NO.';
$lang['install_admin_frontendlang'] = 'V&yacute;choz&iacute; jazyk pro str&aacute;nky (frontend). Toto uprav&iacute; locale pro různ&eacute; funkce zobrazen&iacute; data atd.';
$lang['install_default_encoding'] = 'T&eacute;měř ve v&scaron;ech př&iacute;padech  by mělo b&yacute;t default_encoding nastaveno na utf-8.';
$lang['installer_done'] = '[hotovo]';
$lang['installer_failed'] = '[selhalo]';
$lang['create_permission'] = 'Vytv&aacute;ř&iacute; se opr&aacute;vněn&iacute; ...';
$lang['add_column_sql'] = 'Vkl&aacute;d&aacute; se sloupec do %s tabulky ...';
$lang['update_table_sql'] = 'Aktualizuje se  %s tabulka ...';
$lang['installing_module'] = 'Instaluje se  %s modul ...';
$lang['updating_schema_version'] = 'Aktualizuje se schema verze %s ...';
$lang['upgrade_config'] = 'Aktualizuje se config.php';
$lang['upgrade_config_info'] = 'aktualizace konfigurace';
$lang['upgrade_failed_again'] = 'Jedna nebo v&iacute;ce aktualizac&iacute; selhalo. Opravte, pros&iacute;m, probl&eacute;m a klikněte na tlač&iacute;tko n&iacute;že pro překontrolov&aacute;n&iacute;.';
$lang['upgrade_cache_dirs'] = 'Čist&iacute; se adres&aacute;ře ke&scaron;e';
$lang['cannot_clean_cache_dirs'] = 'Nelze vyčistit adres&aacute;ře ke&scaron;e!';
$lang['upgrade_schema'] = 'Aktualizuje se schema';
$lang['need_upgrade_schema'] = 'CMS potřebuje aktualizovat.<br />Nyn&iacute; se použ&iacute;v&aacute; schema verze %s a je třeba aktualizovat na verzi %s';
$lang['schema_ok'] = 'CMS datab&aacute;ze je aktu&aacute;ln&iacute;. Použ&iacute;v&aacute; se verze %s';
$lang['noneed_upgrade_schema'] = 'CMS datab&aacute;ze je aktu&aacute;ln&iacute;. Použ&iacute;v&aacute; se verze %s';
$lang['upgrade_modules'] = 'Aktualizuj&iacute; se moduly';
$lang['noneed_upgrade_modules'] = 'Moduly j&aacute;dra jsou aktu&aacute;ln&iacute;';
$lang['upgrade_sql_module_from_to'] = 'Aktualizuj&iacute; se SQL modulu &quot;%s&quot; z %s na %s ...';
$lang['upgrade_event_module_from_to'] = 'Aktualizuj&iacute; se eventy modulu &quot;%s&quot; z %s na %s ...';
$lang['sitedown_not_removed'] = 'Nelze odstranit soubor tmp/cache/SITEDOWN. Odstraňte ho pros&iacute;m ručně nebo se bude na Va&scaron;ich str&aacute;nk&aacute;ch zobrazovat zpr&aacute;va &quot;Str&aacute;nky mimo provoz z důvodu &uacute;držby&quot;';
$lang['upgrade_ok'] = 'Zkontrolujte pros&iacute;m config.php, upravte nov&aacute; nastaven&iacute; podle potřeby a pak nastavte opr&aacute;vněn&iacute; zpět do uzamčen&eacute;ho stavu. Tak&eacute; by bylo třeba zkontrolovat moduly zda jsou aktu&aacute;ln&iacute;, projit&iacute;m str&aacute;nky Roz&scaron;&iacute;řen&iacute; -> Moduly a zkontrolov&aacute;n&iacute;m uveden&yacute;ch jako &quot;Požaduj&iacute; aktualizaci&quot;';
$lang['upgrade_complete'] = 'Proces aktualizace kompletn&iacute;';
$lang['upgrade_end'] = 'CMS je aktu&aacute;ln&iacute;. Klikněte pros&iacute;m %s pro přechod na Va&scaron;i CMS str&aacute;nku nebo můžete %s.';
$lang['here'] = 'zde';
$lang['go_to_admin'] = 'přej&iacute;t na Administračn&iacute; panel';
$lang['errorfilenot'] = 'Soubor nenalezen!';
$lang['errorfilenotwritable'] = 'Do souboru nelze zapisovat!';
$lang['nofiles'] = 'Tento zdroj neexistuje!';
$lang['is_directory'] = 'Tento zdroj je adres&aacute;ř!';
$lang['is_readable_false'] = 'Tento zdroj nelze přeč&iacute;st!';
$lang['checksum_match'] = 'Kontroln&iacute; součet souhlas&iacute;!';
$lang['checksum_not_match'] = 'Kontroln&iacute; součet nesouhlas&iacute;!';
$lang['not_checksum'] = 'Nelze st&aacute;hnout kontroln&iacute; součet!';
$lang['format_datetime'] = '%c';
$lang['upload_err_ini_size'] = 'Nahran&yacute; soubor překračuje nastaven&iacute; upload_max_filesize v php.ini!';
$lang['upload_err_form_size'] = 'Nahran&yacute; soubor překračuje nastaven&iacute; MAX_FILE_SIZE zadan&eacute; v HTML formul&aacute;ři.';
$lang['upload_err_partial'] = 'Nahran&yacute; soubor je pouze č&aacute;stečně nahran&yacute;.';
$lang['upload_err_no_file'] = 'Soubor nenahr&aacute;n.';
$lang['upload_err_no_tmp_dir'] = 'Chyb&iacute; dočasn&yacute; formul&aacute;ř.';
$lang['upload_err_cant_write'] = 'Selhal z&aacute;pis souboru na disk.';
$lang['upload_err_extension'] = 'Nahr&aacute;v&aacute;n&iacute; souboru zastaveno roz&scaron;&iacute;řen&iacute;m.';
$lang['upload_err_empty'] = 'Soubor m&aacute; nulovou d&eacute;lku';
$lang['upload_err_unknown'] = 'Nezn&aacute;m&yacute; prob&eacute;m nahr&aacute;v&aacute;n&iacute; souboru.';
$lang['function_file_uploads_off'] = 'file_uploads jsou vypnuty ve Va&scaron;&iacute; php konfiguraci!';
$lang['upload_file_no_readable'] = 'Nahran&yacute; soubor nelze přeč&iacute;st!';
$lang['upload_file_multiple'] = 'V&iacute;cen&aacute;sobn&eacute; nahr&aacute;v&aacute;n&iacute; souborů nen&iacute; povoleno!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes pro operace Get/Post/Cookie';
$lang['test_check_magic_quotes_gpc_failed'] = 'Když jsou magic_quotes zapnuty, v&scaron;echny jednoduch&eacute; uvozovky, dvojit&eacute; uvozovky a zpětn&aacute; lom&iacute;tka jsou eskapov&aacute;ny automaticky zpětn&yacute;m lom&iacute;tkem. Toto může způsobit mnoho probl&eacute;mů v CMS.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes v runtime';
$lang['test_check_magic_quotes_runtime_failed'] = 'Když jsou magic_quotes zapnuty, mnoho funkc&iacute; vracej&iacute;c&iacute;ch data jak&eacute;hokoliv extern&iacute;ho zdroje včetně datab&aacute;z&iacute; a textov&yacute;ch pol&iacute; budou m&iacute;t uvozovky eskapov&aacute;ny zpětn&yacute;m lom&iacute;tkem. Toto bude dělat probl&eacute;my s CMS Made Simple.';
$lang['install_admin_checksum'] = 'Zkontrolujte svou instalaci';
$lang['upgrade_admin_checksum'] = 'Zkontrolujte aktualizaci Va&scaron;eho syst&eacute;mu';
$lang['checksum'] = 'Test kontroln&iacute;ho součtu';
$lang['checksum_file'] = 'Soubor kontroln&iacute;ho součtu';
$lang['install_test_checksum'] = 'Můžete ověřit integritu Va&scaron;ich CMS souborů porovn&aacute;n&iacute;m proti origin&aacute;ln&iacute;mu CMS kontroln&iacute;mu součtu. Pomůže to s odhalen&iacute;m prob&eacute;mu s nahr&aacute;v&aacute;n&iacute;m souborů.';
$lang['checksum_passed'] = 'V&scaron;echny kontroln&iacute; součty souhlas&iacute;!';
$lang['checksum_failed'] = 'Kontroln&iacute; součet souhlas&iacute; s chybami. Projděte n&aacute;povědu pro v&iacute;ce informac&iacute;';
$lang['test_check_open_basedir'] = 'Kontrola PHP Open Basedir';
$lang['test_check_open_basedir_failed'] = 'Open basedir omezen&iacute; jsou v &uacute;činnosti. S t&iacute;mto omezen&iacute;m mohou b&yacute;t probl&eacute;my s funkčnost&iacute; někter&yacute;ch modulů.';
$lang['unlimited'] = 'Neomezeno';
$lang['test_open_basedir_session_save_path'] = 'Open basedir omezen&iacute; vypadaj&iacute; b&yacute;t v &uacute;činnosti. Pokud budete m&iacute;t probl&eacute;my s  SESSION a ini_set funguje, můžete povolit session přes cookies vložen&iacute;m: ini_set(&#039;session.use_only_cookies&#039;, 1);  na zač&aacute;tek souboru include.php';
$lang['install_warn_db_createtables'] = 'Norm&aacute;lně by toto pole mělo b&yacute;t za&scaron;krtnuto vždy. Při zakazov&aacute;n&iacute; t&eacute;to vlastnosti je třeba b&yacute;t opatrn&yacute;';
$lang['install_admin_tablesnotcreated'] = 'Proces kompletn&iacute;. Instalačn&iacute; proces skončil, na V&aacute;&scaron; požadavek nebyly datab&aacute;zov&eacute; tabulky vytvořeny. Přesto byl konfiguračn&iacute; soubor resetov&aacute;n a v&scaron;echny před-instalačn&iacute; testy souhlas&iacute;. Děkujeme a zde je V&aacute;&scaron;';
$lang['info_create_dir_and_file'] = 'Vlastn&iacute;k HTTP procesu nemůže vytvořit soubor uvnitř adres&aacute;ře, kter&yacute; vlastn&iacute;. Toto je pravděpodobně zapnut&yacute;m safe modem. Mnoho funkc&iacute; v CMS Made Simple nebude spr&aacute;vně fungovat s t&iacute;mto nastaven&iacute;m. Pokračov&aacute;n&iacute; nen&iacute; možn&eacute;.';
$lang['test_create_dir_and_file'] = 'Kontroluje se, zda httpd proces může vytvořit soubor uvnitř j&iacute;m vytvořen&eacute;ho adres&aacute;ře.';
$lang['cms_site'] = 'CMS str&aacute;nky';
$lang['or_greater'] = 'Nebo vy&scaron;&scaron;&iacute;';
$lang['sitename'] = 'N&aacute;zev str&aacute;nek';
$lang['warning_safe_mode'] = '<strong><em>VAROV&Aacute;N&Iacute;:</em></strong> PHP Safe mod je povolen.  D&iacute;ky tomuto nastaven&iacute; nebudete moci nahr&aacute;vat soubory přes webov&eacute; rozhran&iacute;, včetně obr&aacute;zků, t&eacute;mat a XML bal&iacute;čků souborů. Doporučujeme kontaktovat va&scaron;eho spr&aacute;vce serveru (webhosting) a pož&aacute;dat ho o zru&scaron;en&iacute; safe m&oacute;du.';
$lang['test'] = 'Test';
$lang['results'] = 'V&yacute;sledky';
$lang['untested'] = 'Netestov&aacute;no';
$lang['owner'] = 'Vlastn&iacute;k';
$lang['permissions'] = 'Opr&aacute;vněn&iacute;';
$lang['off'] = 'Vyp';
$lang['on'] = 'Zap';
$lang['permission_information'] = 'Informace o opr&aacute;vněn&iacute;ch';
$lang['server_os'] = 'Operačn&iacute; syst&eacute;m serveru';
$lang['server_api'] = 'API serveru';
$lang['server_software'] = 'Software serveru';
$lang['server_information'] = 'Informace o serveru';
$lang['session_save_path'] = 'Cesta k &uacute;loži&scaron;ti sessions (sessions save path)';
$lang['max_execution_time'] = 'Maxim&aacute;ln&iacute; doba prov&aacute;děn&iacute; (Maximum execution time)';
$lang['gd_version'] = 'Verze GD';
$lang['upload_max_filesize'] = 'Maxim&aacute;ln&iacute; velikost nahr&aacute;van&eacute;ho souboru (Maximum upload size)';
$lang['post_max_size'] = 'Maxim&aacute;ln&iacute; veilkost dat, zas&iacute;lan&yacute;ch metodou POST (Maximum post size)';
$lang['memory_limit'] = 'Paměťov&yacute; limit v PHP';
$lang['server_db_type'] = 'Datab&aacute;zov&yacute; server';
$lang['server_db_version'] = 'Verze datab&aacute;zov&eacute;ho serveru';
$lang['phpversion'] = 'Verze PHP';
$lang['safe_mode'] = 'PHP Safe Mode';
$lang['php_information'] = 'Informace PHP';
$lang['cms_install_information'] = 'Informace o instalaci CMS';
$lang['cms_version'] = 'Verze CMS';
$lang['systeminfo_copy_paste'] = 'Pros&iacute;m zkop&iacute;rujte tyto informace a vložte je do sv&eacute;ho dotazu ve f&oacute;ru';
$lang['help_systeminformation'] = 'Informace zobrazen&eacute; n&iacute;že poch&aacute;zej&iacute; z mnoha zdrojů . Umožňuj&iacute; l&eacute;pe zjistit př&iacute;činu probl&eacute;mů s Va&scaron;&iacute; instalac&iacute; CMS Made Simple.';
$lang['systeminfo'] = 'Informace o syst&eacute;mu';
$lang['systeminfodescription'] = 'Zobraz&iacute; informace, jež mohou b&yacute;t užitečn&eacute; při diagnostice probl&eacute;mů';
$lang['error'] = 'Chyba';
$lang['new_version_available'] = '<em>Pozn&aacute;mka:</em> Je dostupn&aacute; nov&aacute; verze CMS Made Simple. Pros&iacute;m informujte administr&aacute;tora.';
$lang['info_urlcheckversion'] = 'Pokud je adresa nastavena na &quot;none&quot;, kontrola nebude prov&aacute;děna.<br/>Pokud nen&iacute; vložen ž&aacute;dn&yacute; řetězec, bude použita v&yacute;choz&iacute; adresa.';
$lang['urlcheckversion'] = 'Adresa, pomoc&iacute; kter&eacute; bude kontrolov&aacute;na dostupnost nov&yacute;ch verz&iacute; CMSMS.';
$lang['read'] = 'Čten&iacute;';
$lang['write'] = 'Zapisov&aacute;n&iacute;';
$lang['execute'] = 'Spou&scaron;těn&iacute;';
$lang['group'] = 'Skupina';
$lang['other'] = 'Jin&eacute;';
$lang['global_umask'] = 'Maska vytv&aacute;řen&iacute; souborů (umask)';
$lang['errorcantcreatefile'] = 'Nelze vytvořit soubor (probl&eacute;m s opr&aacute;vněn&iacute;mi?)';
$lang['add'] = 'Přidat';
$lang['about'] = 'Informace o';
$lang['action'] = 'Akce';
$lang['actionstatus'] = 'Akce/Stav';
$lang['active'] = 'Aktivn&iacute;';
$lang['cantremove'] = 'Nelze odebrat';
$lang['changepermissions'] = 'Změnit opr&aacute;vněn&iacute;';
$lang['changepermissionsconfirm'] = 'VAROV&Aacute;N&Iacute;\n\nTato akce prověř&iacute;, zda v&scaron;echny soubory modulu jsou zapisovateln&eacute; web serverem.\nOpravdu chcete pokračovat?';
$lang['success'] = '&Uacute;spěch';
$lang['advanced'] = 'Roz&scaron;&iacute;řen&eacute;';
$lang['back'] = 'Zpět do menu';
$lang['cancel'] = 'Zru&scaron;it';
$lang['cantchmodfiles'] = 'Couldn&#039;t change permissions on some files';
$lang['cantremovefiles'] = 'Probl&eacute;m s odstraňov&aacute;n&iacute;m souborů (Opr&aacute;vněn&iacute;?)';
$lang['create'] = 'Vytvořit';
$lang['database'] = 'Datab&aacute;ze';
$lang['databaseprefix'] = 'Prefix datab&aacute;ze';
$lang['databasetype'] = 'Typ Datab&aacute;ze';
$lang['date'] = 'Datum';
$lang['default'] = 'V&yacute;choz&iacute;';
$lang['delete'] = 'Smazat';
$lang['deleteconfirm'] = 'Jste si jisti, že chcete vymazat - %s - ?';
$lang['description'] = 'Popis';
$lang['directoryexists'] = 'Tento adres&aacute;ř již existuje.';
$lang['down'] = 'Dolů';
$lang['edit'] = 'Upravit';
$lang['email'] = 'E-mailov&aacute; adresa';
$lang['errordeletingfile'] = 'Nelze smazat soubor. Probl&eacute;m s opr&aacute;vněn&iacute;m?';
$lang['errordirectorynotwritable'] = 'Nejsou opr&aacute;vněn&iacute; pro z&aacute;pis do adres&aacute;ře. Toto může b&yacute;t způsobeno opr&aacute;vněn&iacute;mi souboru a vlastnictv&iacute;m. Tak&eacute; může b&yacute;t povolen safe mod.';
$lang['cachenotwritable'] = 'Adres&aacute;ř ke&scaron;e nen&iacute; zapisovateln&yacute;. Vyči&scaron;těn&iacute; ke&scaron;e nebude fungovat. Nastavte, pros&iacute;m, adres&aacute;ři tmp/cache pln&aacute; opr&aacute;vněn&iacute; pro čten&iacute;/z&aacute;pis/spu&scaron;těn&iacute; (chmod 777). Tak&eacute; je třeba zak&aacute;zat safe mod.';
$lang['modulesnotwritable'] = 'Adres&aacute;ř modulů nen&iacute; zapisovateln&yacute;. Pokud budete cht&iacute;t instalovat moduly nahr&aacute;n&iacute;m XML souboru, je třeba nastavit pln&aacute; pr&aacute;va čten&iacute;/z&aacute;pisu/spou&scaron;těn&iacute; (chmod 777) adres&aacute;ři modulů. Tak&eacute; může b&yacute;t aktivn&iacute; safe mod.';
$lang['false'] = 'Ne';
$lang['settrue'] = 'Nastavit Ano';
$lang['filename'] = 'Jm&eacute;no souboru';
$lang['filesize'] = 'Velikost souboru';
$lang['help'] = 'N&aacute;pověda';
$lang['language'] = 'Jazyk';
$lang['lastname'] = 'Př&iacute;jmen&iacute;';
$lang['name'] = 'Jm&eacute;no';
$lang['password'] = 'Heslo';
$lang['passwordagain'] = 'Heslo (znovu)';
$lang['remove'] = 'Odstranit';
$lang['saveconfig'] = 'Uložit config';
$lang['true'] = 'Ano';
$lang['setfalse'] = 'Nastavit Ne';
$lang['type'] = 'Typ';
$lang['typenotvalid'] = 'Typ nen&iacute; spr&aacute;vn&yacute;';
$lang['unknown'] = 'Nezn&aacute;m&yacute;';
$lang['user'] = 'Uživatel';
$lang['userdefinedtags'] = 'Uživatelsky definovan&eacute; tagy';
$lang['usermanagement'] = 'Spr&aacute;va uživatelů';
$lang['username'] = 'Uživatelsk&eacute; jm&eacute;no';
$lang['usernameincorrect'] = 'Uživatelsk&eacute; jm&eacute;no nebo heslo neplatn&eacute;';
$lang['version'] = 'Verze';
$lang['install_title'] = 'Instalace CMS Made Simple (krok %s)';
$lang['install_system'] = 'Instalace syst&eacute;mu';
$lang['install_thanks'] = 'Děkujeme za instalaci CMS Made Simple';
$lang['upgrade_title'] = 'Aktualizace CMS Made Simple (krok %s)';
$lang['upgrade_system'] = 'Aktualizace syst&eacute;mu';
$lang['upgrade_thanks'] = 'Děkujeme za aktualizaci CMS Made Simple na';
$lang['install_please_read'] = 'Přečtěte si pros&iacute;m str&aacute;nku <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Ře&scaron;en&iacute; probl&eacute;mů při instalaci</a> na CMS Made Simple dokumentačn&iacute; Wiki.';
$lang['install_checking'] = 'Kontroluji opr&aacute;vněn&iacute; a PHP nastaven&iacute;';
$lang['install_test'] = 'Test';
$lang['install_result'] = 'V&yacute;sledek';
$lang['install_required_settings'] = 'Požadovan&eacute; nastaven&iacute;';
$lang['install_recommended_settings'] = 'Doporučen&eacute; nastaven&iacute;';
$lang['install_you_have'] = 'M&aacute;te';
$lang['install_legend'] = 'Legenda';
$lang['install_symbol'] = 'Symbol';
$lang['install_definition'] = 'Definice';
$lang['install_value_passed'] = 'Vyžadovan&yacute; test pro&scaron;el';
$lang['install_value_failed'] = 'Vyžadovan&yacute; test selhal';
$lang['install_error_fragment'] = 'Informace ře&scaron;en&iacute; instalačn&iacute;ch probl&eacute;mů';
$lang['install_value_required'] = 'Nastaven&iacute; je pod požadovanou hodnotou';
$lang['install_value_recommended'] = 'Nastaven&iacute; je nad požadovanou hodnotou, ale pod doporučenou hodnotou<br />nebo... Chyb&iacute; schopnost, kter&aacute; <em>může</em> b&yacute;t požadov&aacute;na pro někter&eacute; funkce';
$lang['install_value_exceed'] = 'Nastaven&iacute; vyhovuje doporučen&yacute;m hodnot&aacute;m<br />nebo... Je dostupn&aacute; schopnost, kter&aacute; <em>může</em> b&yacute;t požadov&aacute;na pro někter&eacute; funkce';
$lang['install_test_failed'] = 'Jeden nebo v&iacute;ce testů selhal. St&aacute;le můžete syst&eacute;m nainstalovat, ale někter&eacute; funkce nemus&iacute; pracovat spr&aacute;vně.<br />Napravte pros&iacute;m situaci a klikněte  &quot;Zkusit znovu&quot; nebo klikněte na tlač&iacute;tko pokračovat.';
$lang['install_test_passed'] = 'V&scaron;echny testy pro&scaron;ly (alespoň na minim&aacute;ln&iacute; &uacute;rovni). Klikněte pros&iacute;m na tlač&iacute;tko Pokračovat.';
$lang['install_failed_again'] = 'Jeden nebo v&iacute;ce testů selhalo. Napravte pros&iacute;m probl&eacute;m a klikněte tlač&iacute;tko n&iacute;že pro opakovanou kontrolu.';
$lang['install_try_again'] = 'Zkusit znovu';
$lang['install_continue'] = 'Pokračovat';
$lang['failure'] = 'Chyba';
$lang['caution'] = 'Varov&aacute;n&iacute;';
$lang['install_admin_umask'] = 'Otestovat masku vytv&aacute;řen&iacute; souborů';
$lang['install_test_umask'] = 'Klikněte pros&iacute;m na tlač&iacute;tko Test pro kontrolu vložen&eacute;ho umask ...';
$lang['test_umask_text'] = 'umask (zkr&aacute;cen&yacute; z user file creation mode mask) je funkce v POSIX prostřed&iacute;, kter&aacute; ovlivňuje v&yacute;choz&iacute; m&oacute;d vytv&aacute;řen&iacute; souborů pro nově vytvořen&eacute; soubory a adres&aacute;ře současn&eacute;ho procesu. Kontroluje, kter&eacute; ze souborov&yacute;ch opr&aacute;vněn&iacute; nebudou nastaveny pro nově vytvořen&yacute; soubor.';
$lang['test_check_umask'] = 'V&yacute;sledek testu na souboru vytvořen&eacute;m v';
$lang['test_umask_not_given'] = 'Umask nezad&aacute;n';
$lang['test_check_umask_failed'] = 'Test umask selhal';
$lang['test_username_not_given'] = 'Nezad&aacute;no uživatelsk&eacute; jm&eacute;no!';
$lang['test_username_illegal'] = 'Uživatelsk&eacute; jm&eacute;no obsahuje zak&aacute;zan&eacute; znaky!';
$lang['test_not_both_passwd'] = 'Jedno z hesel je pr&aacute;zdn&eacute;!';
$lang['test_passwd_not_match'] = 'Hesla se neschoduj&iacute;!';
$lang['test_email_accountinfo'] = 'Bylo vybr&aacute;no odesl&aacute;n&iacute; informac&iacute; o &uacute;čtu na e-mail, ale e-mail nebyl zad&aacute;n!';
$lang['test_database_prefix'] = 'Prefix datab&aacute;ze obsahuje nepovolen&eacute; znaky';
$lang['test_no_dbms'] = 'Nebyla vybr&aacute;na dbms!';
$lang['test_could_not_connect_db'] = 'Nepodařilo se připojit k datab&aacute;zi. Zkontrolujte pros&iacute;m zda uživatelsk&eacute; jm&eacute;no a heslo jsou spr&aacute;vn&eacute; a že uživatel m&aacute; opr&aacute;vněn&yacute; př&iacute;stup do t&eacute;to datab&aacute;ze.';
$lang['test_could_not_drop_table'] = 'Nepodařilo se zahodit tabulku. Zkontrolujte zda uživatel m&aacute; pr&aacute;va na zahazov&aacute;n&iacute; tabulek v t&eacute;to datab&aacute;zi.';
$lang['test_could_not_create_table'] = 'Nepodařilo se vytvořit tabulku. Zkontrolujte zda uživatel m&aacute; pr&aacute;va na vytv&aacute;řen&iacute; tabulek v t&eacute;to datab&aacute;zi.';
$lang['test_check_php'] = 'Kontroluje se PHP verzi 4.3+';
$lang['test_min_recommend'] = '(min %s, doporučeno %s)';
$lang['test_min_recommend_plus'] = '(min %s, doporučeno %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple potřebuje php verzi 4.3 a nebo vy&scaron;&scaron;&iacute; (vy m&aacute;te %s), ale PHP %s nebo vy&scaron;&scaron;&iacute; je doporučeno pro zaji&scaron;těn&iacute; maxim&aacute;ln&iacute; kompatibility s moduly třet&iacute;ch stran';
$lang['test_check_md5_func'] = 'Kontroluje se md5 funkce';
$lang['test_check_safe_mode'] = 'Kontroluje se safe mod';
$lang['test_check_safe_mode_failed'] = 'PHP safe mode může působit probl&eacute;m s nahr&aacute;v&aacute;n&iacute;m souborů a s někter&yacute;mi funkcemi. V&scaron;e z&aacute;lež&iacute; na tom, jak hodně striktn&iacute; je nastaven&iacute; na Va&scaron;em serveru.';
$lang['test_check_tokenizer'] = 'Kontroluj&iacute; se tokenizer funkce';
$lang['test_check_tokenizer_failed'] = 'Bez podpory tokenizeru se může st&aacute;t, že v&scaron;echny str&aacute;nky se budou zobrazovat jako čistě b&iacute;l&eacute;. Doporučujeme, aby jste jej nainstalovali, ale Va&scaron;e str&aacute;nky můžou fungovat tak&eacute; bez něj.';
$lang['test_check_gd'] = 'Kontroluje se GD knihovna';
$lang['test_check_gd_failed'] = 'GD knihovna je nezbytn&aacute; pro funkci někter&yacute;ch modulů.';
$lang['test_check_write'] = 'Kontroluj&iacute; se pr&aacute;va z&aacute;pisu na';
$lang['test_may_not_exist'] = 'Tento soubor zat&iacute;m neexistuje. Pokud neexistuje, měli byste založit pr&aacute;zdn&yacute; soubor tohoto jm&eacute;na. Zajistěte tak&eacute;, že tento soubor bude zapisovateln&yacute; webov&yacute;m serverem.';
$lang['could_not_retrieve_a_value'] = 'Nelze z&iacute;skat hodnotu ... přesto se pokračuje.';
$lang['displaying_the_value_originally'] = '<br />Zobrazuje se hodnota původně nastaven&aacute; v konfiguračn&iacute;m souboru (nemus&iacute; to b&yacute;t přesn&eacute;).';
$lang['test_check_xml_func'] = 'Kontroluje se z&aacute;kladn&iacute; podpora XML (expat)';
$lang['test_check_xml_failed'] = 'Podpora XML nen&iacute; zakompilov&aacute;na do Va&scaron;&iacute; instalace php. St&aacute;le můžete syst&eacute;m použ&iacute;vat, ale nebude možn&eacute; použ&iacute;vat ž&aacute;dn&eacute; funkce vzd&aacute;len&eacute; instalace modulů.';
$lang['test_allow_url_fopen_failed'] = 'Pokud je allow url fopen zak&aacute;z&aacute;n, nebude možn&eacute; přistupovat k URL objektům jako jsou soubory přes ftp nebo http protokol.';
$lang['test_remote_url'] = 'Test vzd&aacute;len&eacute; URL';
$lang['test_remote_url_failed'] = 'Pravděpodobně nebudete moci otev&iacute;rat soubor na vzd&aacute;len&eacute;m webov&eacute;m serveru.';
$lang['connection_error'] = 'Vypad&aacute; to, že nefunguj&iacute; odchoz&iacute; http spojen&iacute;! Použ&iacute;v&aacute;te firewall nebo někter&yacute; ACL pro extern&iacute; spojen&iacute;? Způsob&iacute; nefunkčnost spr&aacute;vce modulů a př&iacute;padně jin&yacute;ch funkc&iacute;.';
$lang['remote_connection_timeout'] = 'Spojen&iacute; vypr&scaron;elo!';
$lang['search_string_find'] = 'Spojen&iacute; ok!';
$lang['connection_failed'] = 'Spojen&iacute; selhalo!';
$lang['remote_response_ok'] = 'Vzd&aacute;len&aacute; odpověď: ok!';
$lang['remote_response_404'] = 'Vzd&aacute;len&aacute; odpověď: nenalezeno!';
$lang['remote_response_error'] = 'Vzd&aacute;len&aacute; odpověď: chyba!';
$lang['test_check_file_upload'] = 'Kontroluje se nahr&aacute;v&aacute;n&iacute; souborů';
$lang['test_check_file_failed'] = 'Když je zak&aacute;z&aacute;no nahr&aacute;v&aacute;n&iacute; souborů, nebudete moci použ&iacute;vat ž&aacute;dnou funkci nahr&aacute;v&aacute;n&iacute; souborů obsaženou v CMS Made Simple. Pokud je to možn&eacute;, toto omezen&iacute; by mělo b&yacute;t vypnuto Va&scaron;&iacute;m syst&eacute;mov&yacute;m administr&aacute;torem pro spr&aacute;vn&eacute; použit&iacute; v&scaron;ech vlastnost&iacute; spr&aacute;vy souborů v syst&eacute;mu. Pokračujte opatrně.';
$lang['test_check_memory'] = 'Kontroluje se PHP memory limit';
$lang['test_check_memory_failed'] = 'Nem&aacute;te dostatek paměti pro spr&aacute;vn&yacute; běh CMSMS nebo v&scaron;ech požadovan&yacute;ch modulů. Pokud je to možn&eacute;, pož&aacute;dejte sv&eacute;ho syst&eacute;mov&eacute;ho administr&aacute;tora pro zv&yacute;&scaron;en&iacute; t&eacute;to hodnotu. Pokračujte opatrně.';
$lang['test_check_time_limit'] = 'Kontroluje se PHP time limit';
$lang['test_check_time_limit_failed'] = 'Počet vteřin pro zpracov&aacute;n&iacute; skriptu. Pokud je tato hodnota dosažena, skript vr&aacute;t&iacute; fat&aacute;ln&iacute; chybu.';
$lang['test_check_post_max'] = 'Kontroluje se maxim&aacute;ln&iacute; velikost postu';
$lang['test_check_post_max_failed'] = 'Pravděpodobně nebudete moci odes&iacute;lat (vět&scaron;&iacute;) data. Uvědomte si pros&iacute;m toto omezen&iacute;.';
$lang['test_check_upload_max'] = 'Kontroluje se maxim&aacute;ln&iacute; velikost nahr&aacute;van&eacute;ho souboru';
$lang['test_check_upload_max_failed'] = 'Pravděpodobně nebudete moci nahr&aacute;vat (vět&scaron;&iacute;) soubory přes funkci přiložen&eacute;ho spr&aacute;vce souborů. Uvědomte si pros&iacute;m toto omezen&iacute;.';
$lang['test_check_writable'] = 'Kontroluje se, zda je %s zapisovateln&eacute;';
$lang['test_check_upload_failed'] = 'Do adres&aacute;ře uploads nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat soubory přes Administračn&iacute; panel.';
$lang['test_check_images_failed'] = 'Do adres&aacute;ře images nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat obr&aacute;zky přes Administračn&iacute; panel.';
$lang['test_check_modules_failed'] = 'Do adres&aacute;ře modules nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat moduly přes Administračn&iacute; panel.';
$lang['test_check_file_get_contents'] = 'Kontroluje se file_get_contents';
$lang['test_check_file_get_contents_failed'] = 'Pravděpodobně nebudete moci použ&iacute;vat ž&aacute;dnou funkcionalitu využ&iacute;vaj&iacute;c&iacute; tuto funkci';
$lang['test_check_session_save_path'] = 'Kontroluje se, zda je session.save_path zaposovateln&eacute;';
$lang['test_empty_session_save_path'] = 'Va&scaron;e session.save_path je pr&aacute;zdn&aacute;. PHP bude použ&iacute;vat dočasn&yacute; adres&aacute;ř Va&scaron;eho OS. Pokud budete m&iacute;t prob&eacute;my se SESSION a ini_set pracuje, můžete zkusit nastavit session přes cookies vložen&iacute;m: ini_set(&#039;session.use_only_cookies&#039;, 1);  na zač&aacute;tek souboru include.php';
$lang['test_check_session_save_path_failed'] = 'Va&scaron;e session.save_path je &quot;%s&quot;. Pokud tam nejde zapisovat, nemus&iacute; b&yacute;t funkčn&iacute; přihla&scaron;ov&aacute;n&iacute; do Administračn&iacute;ho panelu. Pokud tomu tak bude, je třeba tuto cestu nastavit zapisovatelnou. Tento test tak&eacute; selže, pokud je povolen safe mod (viz. n&iacute;že).';
$lang['test_check_ini_set'] = 'Kontroluje se, zda je možn&eacute; použ&iacute;vat ini_set';
$lang['test_check_ini_set_failed'] = 'Ačkoliv možnost měnit nastaven&iacute; v souboru php.ini nen&iacute; povinn&aacute;, někter&aacute; roz&scaron;&iacute;řen&iacute; mohou tato nastaven&iacute; potřebovat (např. pro možnost nahr&aacute;vat vět&scaron;&iacute; soubory). Tento test může selhat, pokud je povolen safe_mode v php.';
$lang['install_admin_header'] = 'Informace o administr&aacute;torsk&eacute;m &uacute;čtu';
$lang['install_admin_info'] = 'Vyberte uživatelsk&eacute; jm&eacute;no, heslo a emailovou adresu pro V&aacute;&scaron; administr&aacute;torsk&yacute; &uacute;čet. Tyto &uacute;daje si pros&iacute;m poznamenejte, bez nich se nen&iacute; možno přihl&aacute;sit do administračn&iacute;ho rozhran&iacute;.';
$lang['install_admin_email'] = 'E-mailov&aacute; adresa';
$lang['install_admin_email_info'] = 'Odeslat informace o vytv&aacute;řen&eacute;m &uacute;čtu e-mailem.';
$lang['install_admin_email_note'] = '<strong>Pozn&aacute;mka:</strong> Tato funkce použ&iacute;v&aacute; funkci mail v php. Pokud neobdrž&iacute;te tento e-mail, může to znamenat, že server nen&iacute; spr&aacute;vně nakonfigurov&aacute;n a měli byste kontaktovat administr&aacute;tora (podporu) hostingu.';
$lang['install_admin_sitename'] = 'Toto je jm&eacute;no Va&scaron;&iacute; str&aacute;nky. Bude použito na různ&yacute;ch m&iacute;stech v&yacute;choz&iacute;ch &scaron;ablon a kdekoliv, kam zad&aacute;te tag {sitename}.';
$lang['install_admin_db'] = 'Informace o datab&aacute;zi';
$lang['install_admin_db_info'] = '<p>Ujistěte se, že jste vytvořili datab&aacute;zi a přidělili uživateli, kter&eacute;ho hodl&aacute;te použ&iacute;vat.</p>
<p>Pro MySQL postupujte n&aacute;sleduj&iacute;c&iacute;m způsobem:</p>
<p>Přihla&scaron;te se do MySQL z konzole a zadejte n&aacute;sleduj&iacute;c&iacute; př&iacute;kazy:</p>
<ol>
<li>create database cms; (můžete použ&iacute;t jak&eacute;koliv jm&eacute;no bez diakritiky a mezer)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;; (kde cms_user je jm&eacute;no uživatele a cms_pass je heslo, jež hodl&aacute;te použ&iacute;vat)</li>
</ol>
<p>Ve&scaron;ker&eacute; zadan&eacute; &uacute;daje si poznamenejte a zadejte je na t&eacute;to str&aacute;nce.';
$lang['install_admin_follow'] = 'Pros&iacute;m vyplňte n&aacute;sleduj&iacute;c&iacute; &uacute;daje';
$lang['install_admin_db_type'] = 'Typ datab&aacute;ze';
$lang['install_admin_no_db'] = 'Va&scaron;e instalace PHP nebyla zkompilov&aacute;na s podporou datab&aacute;zov&yacute;ch ovladačů. Pros&iacute;m zajistěte instalaci podporu mysql, mysqli a/nebo postgres7 a pak to zkuste znovu.';
$lang['install_admin_db_host'] = 'Adresa datab&aacute;zov&eacute;ho serveru';
$lang['install_admin_db_name'] = 'Jm&eacute;no datab&aacute;ze';
$lang['install_admin_db_create'] = 'Vytvořit tabulky (Varov&aacute;n&iacute;: Vymaže existuj&iacute;c&iacute; data)';
$lang['install_admin_db_prefix'] = 'Prefix tabulky';
$lang['install_admin_db_sample'] = 'Instalovat vzorek dat a &scaron;ablon';
$lang['retry'] = 'Znovu';
$lang['install_admin_db_create_seq'] = 'Vytv&aacute;ř&iacute; se %s table sequence...';
$lang['install_admin_importing'] = 'Importuje se vzorek dat...';
$lang['invalid_query'] = 'Chybn&yacute; dotaz: %s';
$lang['install_creating_table'] = '<p>Vytv&aacute;ř&iacute; se tabulka %s...';
$lang['install_creating_index'] = '<p>Vytv&aacute;ř&iacute; se index v tabulce %s... [%s]</p>';
$lang['done'] = 'hotovo';
$lang['failed'] = 'selhalo';
$lang['install_admin_error_schema'] = 'Chyba při vyzved&aacute;v&aacute;n&iacute; SQL sch&eacute;matu';
$lang['install_admin_set_account'] = 'Nastavuje se &uacute;čet administr&aacute;tora...';
$lang['install_admin_set_sitename'] = 'Nastavuje se jm&eacute;no str&aacute;nek...';
$lang['install_admin_setup'] = 'Nyn&iacute; bude pokračovat nastaven&iacute; konfiguračn&iacute;ho souboru, mnoho potřebn&yacute;ch věc&iacute; už je hotov&yacute;ch. Možnost je nechat v&scaron;echny tyto hodnoty jak jsou, stač&iacute; kliknout na Pokračovat.';
$lang['install_admin_docroot'] = 'CMS Document root (z pohledu webserveru)';
$lang['install_admin_docroot_path'] = 'Cesta k Document rootu';
$lang['install_admin_querystring'] = 'Řetězec dotazu (ponechte toto pole beze změny pokud v&scaron;e funguje spr&aacute;vně, později můžete nastavit v souboru config.php)';
$lang['invalid_querys'] = '<b>VAROV&Aacute;N&Iacute;<b/>: Nespr&aacute;vn&eacute; dotazy na datab&aacute;zi!';
$lang['install_admin_sitedown'] = 'Chyba: Nemohu odebrat soubor tmp/cache/SITEDOWN. Pros&iacute;m odeberte soubor ručně.';
$lang['install_admin_update_hierarchy'] = 'Aktualizuj&iacute; se hierarchick&eacute; pozice...';
$lang['install_admin_set_core_event'] = 'Nastavuj&iacute; se ud&aacute;losti j&aacute;dra...';
$lang['install_admin_install_modules'] = 'Instaluj&iacute; se moduly...';
$lang['install_admin_index_search'] = 'Vytv&aacute;ř&iacute; se index pro hled&aacute;n&iacute;...';
$lang['install_admin_clear_cache'] = 'Čist&iacute; se cache str&aacute;nek (pokud existuje)...';
$lang['install_admin_emailing'] = 'Odes&iacute;laj&iacute; se informace o administr&aacute;torsk&eacute;m &uacute;čtu e-mailem...';
$lang['install_admin_congratulations'] = 'Gratulujeme, v&scaron;echna nastaven&iacute; byla provedena - zde je va&scaron;e <a href="%s">nov&aacute; str&aacute;nka</a>';
$lang['could_not_connect_db'] = 'Nelze se připojit do datab&aacute;ze. Ověřte pros&iacute;m spr&aacute;vnost uživatelsk&eacute;ho jm&eacute;na a hesla, a opr&aacute;vněn&iacute; uživatele přistupovat k dan&eacute; datab&aacute;zi.';
$lang['cannot_write_config'] = 'Chyba: Nelze zapisovat do %s.';
$lang['email_accountinfo_subject'] = 'Informace administr&aacute;torsk&eacute;ho &uacute;čtu CMS Made Simple';
$lang['email_accountinfo_message'] = 'Děkujeme za instalaci CMS Made Simple.

Informace o Va&scaron;em nov&eacute;m &uacute;čtu:
uživatelsk&eacute; jm&eacute;no: %s
heslo: %s

Přihl&aacute;sit do administrace se můžete zde: %s';
$lang['utma'] = '156861353.3769824904990279700.1249913289.1261996808.1263200482.16';
$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = '1229762881-19854751-99654968';
$lang['utmb'] = '156861353.1.10.1263200482';
$lang['utmc'] = '156861353';
?>